package com.stats.excel.statsexcel.service.impl;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.SyncReadListener;
import com.alibaba.excel.exception.ExcelDataConvertException;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.stats.excel.statsexcel.dbo.UserDBO;
import com.stats.excel.statsexcel.mapper.UserMapper;
import com.stats.excel.statsexcel.service.ExcelService;
import com.stats.excel.statsexcel.utils.converter.LocalDateConverter;
import javafx.stage.FileChooser;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.File;
import java.util.List;
import java.util.Map;

@Service
@Slf4j
public class ExcelServiceImpl extends ServiceImpl<UserMapper, UserDBO> implements ExcelService {
    @Override
    public void readExcels(List<UserDBO> resultUser, File file) {
        log.info("文件名称" + file.getName());
        EasyExcel.read(file, UserDBO.class, new SyncReadListener() {
            //读取每一行进行的操作
            @Override
            public void invoke(Object object, AnalysisContext context) {
                UserDBO user = (UserDBO) object;
                if (user.getUserAge() <= 200&&user.getUserAge() > 18) {
                    resultUser.add(user);
                }
            }

            @Override
            public void onException(Exception exception, AnalysisContext context) throws Exception {
                log.info("解析出错：" + exception.getMessage());
                int row = 0, column = 0;
                if (exception instanceof ExcelDataConvertException) {
                    ExcelDataConvertException convertException = (ExcelDataConvertException) exception;
                    row = convertException.getRowIndex();
                    column = convertException.getColumnIndex();
                    log.error("解析出错：{}行 {}列", row, column);
                }
            }

            //读取表头
            @Override
            public void invokeHeadMap(Map<Integer, String> headMap, AnalysisContext context) {
                log.info("表头信息:" + headMap);
            }
        }).headRowNumber(1).registerConverter(new LocalDateConverter()).doReadAll();//.headRowNumber(1)表示从第几行开始读取，有的文件title不在第一行
    }

    @Override
    public void configureFileChooser(FileChooser fileChooser) {
        fileChooser.setTitle("请选择你想要的文件");//设置文件选择器打开时候的提示标题
        fileChooser.setInitialDirectory(//设置文件选择器的初始化打开目录
                new File(System.getProperty("user.home") + "/Desktop")//引向操作系统的用户名目录
        );
        fileChooser.getExtensionFilters().addAll(//设置文件选择器所能打开的文件类型（利用给文件选择器对象添加扩展名过滤器功能来实现）
//                new FileChooser.ExtensionFilter("All Images", "*.*"),//所有格式类型过滤器
                new FileChooser.ExtensionFilter("XLSX", "*.xlsx"),//.jpg图片格式类型过滤器
                new FileChooser.ExtensionFilter("XLS", "*.xls"),//.png图片格式类型过滤器
                new FileChooser.ExtensionFilter("XLSM", "*.xlsm")//.png图片格式类型过滤器
        );
    }
}
